@@ -387,27 +387,27 @@ GMH323EndPoint::AddVideoCapabilities ()
     if (autoStartTransmitVideo && !autoStartReceiveVideo) {
       
       /* CIF Capability in first position */
-      AddCapability (new H323_H261Capability (0, 4, FALSE, FALSE, 6217));
-      AddCapability (new H323_H261Capability (2, 0, FALSE, FALSE, 6217));
+      AddCapability (new H323_H261Capability (0, 1, FALSE, FALSE, 6217));
+      AddCapability (new H323_H261Capability (1, 0, FALSE, FALSE, 6217));
     }
     else {
 
       /* CIF Capability in first position */
-      SetCapability (0, 1, new H323_H261Capability (0, 4, FALSE, FALSE, 6217));
-      SetCapability (0, 1, new H323_H261Capability (2, 0, FALSE, FALSE, 6217));
+      SetCapability (0, 1, new H323_H261Capability (0, 1, FALSE, FALSE, 6217));
+      SetCapability (0, 1, new H323_H261Capability (1, 0, FALSE, FALSE, 6217));
     }
   }
   else {
 
     if (autoStartTransmitVideo && !autoStartReceiveVideo) {
       
-      AddCapability (new H323_H261Capability (2, 0, FALSE, FALSE, 6217)); 
-      AddCapability (new H323_H261Capability (0, 4, FALSE, FALSE, 6217));
+      AddCapability (new H323_H261Capability (1, 0, FALSE, FALSE, 6217)); 
+      AddCapability (new H323_H261Capability (0, 1, FALSE, FALSE, 6217));
     }
     else {
 
-      SetCapability (0, 1, new H323_H261Capability (2, 0, FALSE, FALSE, 6217)); 
-      SetCapability (0, 1, new H323_H261Capability (0, 4, FALSE, FALSE, 6217));
+      SetCapability (0, 1, new H323_H261Capability (1, 0, FALSE, FALSE, 6217)); 
+      SetCapability (0, 1, new H323_H261Capability (0, 1, FALSE, FALSE, 6217));
     }
   }
 }
@@ -1190,6 +1190,11 @@ GMH323EndPoint::GetRemoteConnectionInfo (H323Connection & connection,
     transport = connection.GetSignallingChannel ();
     if (transport) 
       remote_ip = transport->GetRemoteAddress ().GetHostName ();
+
+    if (remote_ip.Find ("::") != P_MAX_INDEX) { // IPv6 notation
+
+      remote_ip = "[" + remote_ip + "]";
+    }
   }
 
   remote_ip = GMURL ().GetDefaultURL () + remote_ip;
@@ -2121,9 +2126,7 @@ GMH323EndPoint::OnRTPTimeout (PTimer &, INT)
   gdk_threads_enter ();
   gm_main_window_flash_message (main_window, msg);
 
-  if (gm_conf_get_int (USER_INTERFACE_KEY "main_window/control_panel_section") 
-      == 0)
-    gm_main_window_update_stats (main_window,
+  gm_main_window_update_stats (main_window,
 			     lost_packets_per,
 			     late_packets_per,
 			     (int) rtt,
@@ -2311,12 +2314,10 @@ GMH323EndPoint::OnOutgoingCall (PTimer &,
 
 BOOL 
 GMH323EndPoint::DeviceVolume (PSoundChannel *sound_channel,
-                              BOOL is_encoding,
-                              BOOL set, 
+			      BOOL is_encoding,
+			      BOOL set, 
 			      unsigned int &vol) 
 {
-  H323Connection *con = NULL;
-
 #ifdef HAS_IXJ
   GMLid *l = NULL;
 #endif
@@ -2326,46 +2327,37 @@ GMH323EndPoint::DeviceVolume (PSoundChannel *sound_channel,
 
   call_token = GetCurrentCallToken ();
 
-  con = FindConnectionWithLock (call_token);
-
-  if (con) {
-
 #ifdef HAS_IXJ
-    if (set) {
+  if (set) {
 
-      l = GetLid ();
-      if (l) {
+    l = GetLid ();
+    if (l) {
 
-        l->SetVolume (is_encoding, vol);
-        l->Unlock ();
+      l->SetVolume (is_encoding, vol);
+      l->Unlock ();
 
-        con->Unlock ();
-
-        return TRUE; /* Ignore the sound channel if a LID is used. Hopefully,
-                        OpenH323 will be fixed soon */
-      }
+      return TRUE; /* Ignore the sound channel if a LID is used. Hopefully,
+		      OpenH323 will be fixed soon */
     }
+  }
 #endif
 
 
-    /* TRUE = from_remote = playing */
-    if (sound_channel) {
+  /* TRUE = from_remote = playing */
+  if (sound_channel) {
 
-      if (set) {
+    if (set) {
 
-        err = 
-          sound_channel->SetVolume (vol)
-          && err;
-      }
-      else {
-
-        err = 
-          sound_channel->GetVolume (vol)
-          && err;
-      }
+      err = 
+	sound_channel->SetVolume (vol)
+	&& err;
     }
+    else {
 
-    con->Unlock ();
+      err = 
+	sound_channel->GetVolume (vol)
+	&& err;
+    }
   }
 
   return err;
