@@ -42,15 +42,14 @@
 #include "videograbber.h"
 #include "gnomemeeting.h"
 #include "misc.h"
-#include "tools.h"
+#include "log_window.h"
+#include "main_window.h"
+#include "druid.h"
 
 #include "dialog.h"
-#include "gconf_widgets_extensions.h"
+#include "gm_conf.h"
 
 
-/* Declarations */
-extern GtkWidget *gm;
-
 
 /* The functions */
 GMVideoGrabber::GMVideoGrabber (BOOL start_grabbing,
@@ -66,8 +65,6 @@ GMVideoGrabber::GMVideoGrabber (BOOL start_grabbing,
   colour = 0;
   contrast = 0;
 
-  gw = GnomeMeeting::Process ()->GetMainWindow ();
-
   
   /* Internal state */
   stop = FALSE;
@@ -83,7 +80,6 @@ GMVideoGrabber::GMVideoGrabber (BOOL start_grabbing,
 
   if (synchronous)
     VGOpen ();
-
   
   /* Start the thread */
   this->Resume ();
@@ -263,6 +259,9 @@ GMVideoGrabber::Unlock ()
 void
 GMVideoGrabber::VGOpen (void)
 {
+  GtkWidget *history_window = NULL;
+  GtkWidget *main_window = NULL;
+
   GMH323EndPoint *ep = NULL;
   
   PString input_device;
@@ -271,7 +270,7 @@ GMVideoGrabber::VGOpen (void)
   gchar *dialog_title = NULL;
   gchar *dialog_msg = NULL;
   gchar *tmp_msg = NULL;
-  gchar *gconf_value = NULL;
+  gchar *conf_value = NULL;
   
   int error_code = 0;
   int channel = 0;
@@ -282,26 +281,28 @@ GMVideoGrabber::VGOpen (void)
   PVideoDevice::VideoFormat format = PVideoDevice::PAL;
 
   ep = GnomeMeeting::Process ()->Endpoint ();
+  history_window = GnomeMeeting::Process ()->GetHistoryWindow ();
+  main_window = GnomeMeeting::Process ()->GetMainWindow ();
   
   if (!is_opened) {
     
-    /* Get the video device options from the GConf database */
+    /* Get the video device options from the configuration database */
     gnomemeeting_threads_enter ();
 
-    gconf_value = gconf_get_string (VIDEO_DEVICES_KEY "input_device");
-    input_device = gconf_value;
-    g_free (gconf_value);
+    conf_value = gm_conf_get_string (VIDEO_DEVICES_KEY "input_device");
+    input_device = conf_value;
+    g_free (conf_value);
     
-    gconf_value = gconf_get_string (VIDEO_DEVICES_KEY "plugin");
-    plugin = gconf_value;
-    g_free (gconf_value);
+    conf_value = gm_conf_get_string (VIDEO_DEVICES_KEY "plugin");
+    plugin = conf_value;
+    g_free (conf_value);
     
-    channel = gconf_get_int (VIDEO_DEVICES_KEY "channel");
+    channel = gm_conf_get_int (VIDEO_DEVICES_KEY "channel");
 
-    size = gconf_get_int (VIDEO_DEVICES_KEY "size");
+    size = gm_conf_get_int (VIDEO_DEVICES_KEY "size");
 
     format =
-      (PVideoDevice::VideoFormat) gconf_get_int (VIDEO_DEVICES_KEY "format");
+      (PVideoDevice::VideoFormat) gm_conf_get_int (VIDEO_DEVICES_KEY "format");
 
     height = (size == 0) ? GM_QCIF_HEIGHT : GM_CIF_HEIGHT; 
     width = (size == 0) ? GM_QCIF_WIDTH : GM_CIF_WIDTH;
@@ -314,7 +315,10 @@ GMVideoGrabber::VGOpen (void)
     if (!no_device_found) {
  
       gnomemeeting_threads_enter ();
-      gnomemeeting_log_insert (_("Opening video device %s with plugin %s"), (const char *) input_device, (const char *) plugin);
+      gm_history_window_insert (history_window,
+				_("Opening video device %s with plugin %s"),
+				(const char *) input_device,
+				(const char *) plugin);
       gnomemeeting_threads_leave ();
 
       var_mutex.Wait ();
@@ -339,7 +343,10 @@ GMVideoGrabber::VGOpen (void)
       if (!error_code) {
 
 	gnomemeeting_threads_enter ();
-	gnomemeeting_log_insert (_("Successfully opened video device %s, channel %d"), (const char *) input_device, channel);
+	gm_history_window_insert (history_window,
+				  _("Successfully opened video device %s, channel %d"),
+				  (const char *) input_device,
+				  channel);
 	gnomemeeting_threads_leave ();
       }
       else {
@@ -353,7 +360,8 @@ GMVideoGrabber::VGOpen (void)
 
 	/* Translators: Do not translate MovingLogo and Picture */
 	tmp_msg = g_strdup (_("A moving GnomeMeeting logo will be transmitted during calls. Notice that you can always transmit a given image or the moving GnomeMeeting logo by choosing \"Picture\" as video plugin and \"MovingLogo\" or \"StaticPicture\" as device."));
-	gnomemeeting_log_insert (_("Couldn't open the video device"));
+	gm_history_window_insert (history_window, 
+				  _("Couldn't open the video device"));
 	switch (error_code) {
 	  
 	case 1:
@@ -381,7 +389,7 @@ GMVideoGrabber::VGOpen (void)
 	  break;
 	}
 
-	gnomemeeting_warning_dialog_on_widget (GTK_WINDOW (gm),
+	gnomemeeting_warning_dialog_on_widget (GTK_WINDOW (main_window),
 					       VIDEO_DEVICES_KEY "enable_preview",
 					       dialog_title,
 					       dialog_msg);
@@ -416,7 +424,8 @@ GMVideoGrabber::VGOpen (void)
 	grabber->SetFrameSizeConverter (width, height, FALSE);
 	
 	gnomemeeting_threads_enter ();
-	gnomemeeting_log_insert (_("Opened the video device using the \"Picture\" video plugin"));
+	gm_history_window_insert (history_window,
+				  _("Opened the video device using the \"Picture\" video plugin"));
 	gnomemeeting_threads_leave ();
       }
       var_mutex.Signal ();
@@ -428,7 +437,7 @@ GMVideoGrabber::VGOpen (void)
 
     var_mutex.Wait ();
     video_channel = new PVideoChannel ();
-    encoding_device = new GDKVideoOutputDevice (1, gw);
+    encoding_device = new GDKVideoOutputDevice (1);
     encoding_device->SetColourFormatConverter ("YUV420P");
 
     if (grabber)
@@ -443,22 +452,39 @@ GMVideoGrabber::VGOpen (void)
       
     /* Setup the video settings */
     GetParameters (&whiteness, &brightness, &colour, &contrast);
-    gnomemeeting_threads_enter ();
-    GTK_ADJUSTMENT (gw->adj_brightness)->value = brightness;
-    GTK_ADJUSTMENT (gw->adj_whiteness)->value = whiteness;
-    GTK_ADJUSTMENT (gw->adj_colour)->value = colour;
-    GTK_ADJUSTMENT (gw->adj_contrast)->value = contrast;
-    gtk_widget_queue_draw (GTK_WIDGET (gw->video_settings_frame));
-    gtk_widget_set_sensitive (GTK_WIDGET (gw->video_settings_frame),
-			      TRUE);
-    gnomemeeting_threads_leave ();
+    if (whiteness > 0 || brightness > 0 || colour > 0 || contrast > 0) {
 
+      gnomemeeting_threads_enter ();
+      gm_main_window_set_video_sliders_values (main_window,
+					       whiteness,
+					       brightness,
+					       colour, 
+					       contrast);
+      gnomemeeting_threads_leave ();
+    }
+    else {
+
+      /* Driver made a reset, keep the old values */
+      gnomemeeting_threads_enter ();
+      gm_main_window_get_video_sliders_values (main_window,
+					       whiteness,
+					       brightness,
+					       colour,
+					       contrast);
+      gnomemeeting_threads_leave ();
+
+      SetWhiteness (whiteness << 8);
+      SetBrightness (brightness << 8);
+      SetColour (colour << 8);
+      SetContrast (contrast << 8);
+    }
+    
       
     /* Update the GUI sensitivity if not in a call */
     if (ep->GetCallingState () == GMH323EndPoint::Standby) {
 
       gnomemeeting_threads_enter ();      
-      gnomemeeting_menu_update_sensitivity (TRUE, FALSE, TRUE);
+      gm_main_window_update_sensitivity (main_window, TRUE, FALSE, TRUE);
       gnomemeeting_threads_leave ();
     }
   }
@@ -470,8 +496,11 @@ GMVideoGrabber::VGClose ()
 {
   GMH323EndPoint *ep = NULL;
 
+  GtkWidget *main_window = NULL;
+
   ep = GnomeMeeting::Process ()->Endpoint ();
-  
+  main_window = GnomeMeeting::Process ()->GetMainWindow ();
+
   if (is_opened) {
 
     var_mutex.Wait ();
@@ -479,20 +508,19 @@ GMVideoGrabber::VGClose ()
     if (video_channel) 
       delete (video_channel);
     var_mutex.Signal ();
-    
-    
+
+
     /* Update menu sensitivity if we are not in a call */
     gnomemeeting_threads_enter ();
-     if (ep->GetCallingState () == GMH323EndPoint::Standby
-	&& !gconf_get_bool (VIDEO_DEVICES_KEY "enable_preview")) {
-      
-      gnomemeeting_menu_update_sensitivity (TRUE, FALSE, FALSE);
-      gnomemeeting_init_main_window_logo (gw->main_video_image);
+    if (ep->GetCallingState () == GMH323EndPoint::Standby
+	&& !gm_conf_get_bool (VIDEO_DEVICES_KEY "enable_preview")) {
+
+      gm_main_window_update_sensitivity (main_window, TRUE, FALSE, FALSE);
+      gm_main_window_update_logo (main_window);
     }
-    gtk_widget_set_sensitive (GTK_WIDGET (gw->video_settings_frame), FALSE);
     gnomemeeting_threads_leave ();
-    
-    
+
+
     /* Initialisation */
     var_mutex.Wait ();
     video_channel = NULL;
@@ -514,7 +542,6 @@ GMVideoTester::GMVideoTester (gchar *m,
 			      gchar *r)
   :PThread (1000, AutoDeleteThread)
 {
-#ifndef DISABLE_GNOME
   if (m)
     video_manager = PString (m);
   if (r)
@@ -525,23 +552,18 @@ GMVideoTester::GMVideoTester (gchar *m,
   
   this->Resume ();
   thread_sync_point.Wait ();
-#endif
 }
 
 
 GMVideoTester::~GMVideoTester ()
 {
-#ifndef DISABLE_GNOME
  PWaitAndSignal m(quit_mutex);
-#endif
 }
 
 
 void GMVideoTester::Main ()
 {
-#ifndef DISABLE_GNOME
-  GmWindow *gw = NULL;
-  GmDruidWindow *dw = NULL;
+  GtkWidget *druid_window = NULL;
 
   PVideoInputDevice *grabber = NULL;
   
@@ -553,9 +575,8 @@ void GMVideoTester::Main ()
   gchar *dialog_msg = NULL;
   gchar *tmp = NULL;
 
-  gw = GnomeMeeting::Process ()->GetMainWindow ();
-  dw = GnomeMeeting::Process ()->GetDruidWindow ();
-
+  druid_window = GnomeMeeting::Process ()->GetDruidWindow (); 
+  
   PWaitAndSignal m(quit_mutex);
   thread_sync_point.Signal ();
 
@@ -568,7 +589,7 @@ void GMVideoTester::Main ()
   gdk_threads_enter ();
   test_dialog =
     gtk_dialog_new_with_buttons ("Video test running",
-				 GTK_WINDOW (gw->druid_window),
+				 GTK_WINDOW (druid_window),
 				 (GtkDialogFlags) (GTK_DIALOG_MODAL),
 				 GTK_STOCK_OK,
 				 GTK_RESPONSE_ACCEPT,
@@ -592,8 +613,9 @@ void GMVideoTester::Main ()
 		    G_CALLBACK (gtk_widget_hide_on_delete), NULL);
 
   gtk_window_set_transient_for (GTK_WINDOW (test_dialog),
-				GTK_WINDOW (gw->druid_window));
-  gtk_widget_show_all (test_dialog);
+				GTK_WINDOW (druid_window));
+  gtk_widget_show_all (GTK_DIALOG (test_dialog)->vbox);
+  gnomemeeting_threads_dialog_show (test_dialog);
   gdk_threads_leave ();
 
   
@@ -682,7 +704,7 @@ void GMVideoTester::Main ()
     }
 
     gdk_threads_enter ();
-    gnomemeeting_error_dialog (GTK_WINDOW (gw->druid_window),
+    gnomemeeting_error_dialog (GTK_WINDOW (druid_window),
 			       _("Failed to open the device"),
 			       dialog_msg);
     gdk_threads_leave ();
@@ -691,10 +713,8 @@ void GMVideoTester::Main ()
   }
 
   gdk_threads_enter ();
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dw->video_test_button),
-				FALSE);
+  gm_druid_window_set_test_buttons_sensitivity (druid_window, FALSE);
   if (test_dialog)
     gtk_widget_destroy (test_dialog);
   gdk_threads_leave ();
-#endif
 }
